@@ -506,7 +506,6 @@ public class EpubCSSCheckCSSHandler implements CssContentHandler, CssErrorHandle
   {
     if (!isGlobalFixedFormat || hasIndividualFixedFormatDocuments)
     {
-      MessageId id = hasIndividualFixedFormatDocuments ? MessageId.CSS_027 : MessageId.CSS_017;
       if ("position".compareToIgnoreCase(declaration.getName().get()) == 0)
       {
         for (CssGrammar.CssConstruct construct : declaration.getComponents())
@@ -514,7 +513,7 @@ public class EpubCSSCheckCSSHandler implements CssContentHandler, CssErrorHandle
           if (construct.getType() == CssGrammar.CssConstruct.Type.KEYWORD &&
               "absolute".compareToIgnoreCase(construct.toCssString()) == 0)
           {
-            getReport().message(id, getCorrectedEPUBLocation(path, declaration.getLocation().getLine(), declaration.getLocation().getColumn(), declaration.toCssString()), declaration.getName().get());
+            getReport().message(MessageId.CSS_017, getCorrectedEPUBLocation(path, declaration.getLocation().getLine(), declaration.getLocation().getColumn(), declaration.toCssString()), declaration.getName().get());
             break;
           }
         }
@@ -582,6 +581,14 @@ public class EpubCSSCheckCSSHandler implements CssContentHandler, CssErrorHandle
               // report absolute font-size as ACC USAGE message
               getReport().message(id, getCorrectedEPUBLocation(path, declaration.getLocation().getLine(), declaration.getLocation().getColumn(), declaration.toCssString()), construct.toCssString());
               break;
+            case INTEGER:
+              // issue #922: "0" should be allowed as font-size
+              if (!quantity.toCssString().equals("0"))
+              {
+                // report unsupported font-size as ERROR message
+                getReport().message(MessageId.CSS_020, getCorrectedEPUBLocation(path, declaration.getLocation().getLine(), declaration.getLocation().getColumn(), declaration.toCssString()), construct.toCssString());
+              }
+              break;
             default:
               // report unsupported font-size as ERROR message
               getReport().message(MessageId.CSS_020, getCorrectedEPUBLocation(path, declaration.getLocation().getLine(), declaration.getLocation().getColumn(), declaration.toCssString()), construct.toCssString());
@@ -713,6 +720,11 @@ public class EpubCSSCheckCSSHandler implements CssContentHandler, CssErrorHandle
         case EXS:
         case LENGTH:
           return true;
+        case INTEGER:
+          if ("0".equals(quantity.toCssString()))
+          {
+            return true;
+          }
       }
     }
     return false;
