@@ -1,6 +1,6 @@
 package com.adobe.epubcheck.vocab;
 
-public class DataNavVocab
+public final class DataNavVocab
 {
   public static final String URI = "http://www.idpf.org/epub/vocab/structure/#";
   public static final EnumVocab<EPUB_TYPES> VOCAB = new EnumVocab<EPUB_TYPES>(EPUB_TYPES.class,
@@ -10,4 +10,6 @@ public class DataNavVocab
   {
     REGION_BASED;
   }
+  
+  private DataNavVocab() {}
 }
